Index: trunk/archive/pslib/include/psBitMask.h
===================================================================
--- trunk/archive/pslib/include/psBitMask.h	(revision 213)
+++ trunk/archive/pslib/include/psBitMask.h	(revision 238)
@@ -1,4 +1,4 @@
-#if !defined (PS_BIT_MASK_H)
-#define PS_BIT_MASK_H
+# if !defined (PS_BIT_MASK_H)
+# define PS_BIT_MASK_H
 
 /** A bitmask of arbitrary length. */
@@ -20,5 +20,5 @@
 /** Set a bit mask */
 psBitMask *
-psSetBitMask(psBitMask *outMask,	//!< Output bit mask or NULL
+psBitMaskSet(psBitMask *outMask,	//!< Output bit mask or NULL
 	     const psBitMask *myMask,	//!< Input bit mask
 	     int bit			//!< Bit to set
@@ -27,21 +27,15 @@
 /** Check a bit mask.  Returns true or false */
 int
-psCheckBitMask(const psBitMask *checkMask, //!< Bit mask to check
-	       int bit			//!< Bit to check
+psBitMaskTest(const psBitMask *checkMask, //!< Bit mask to check
+	      int bit			//!< Bit to check
     );
 
 /** OR two bit masks */
 psBitMask *
-psOrBitMasks(psBitMask *outMask,	//!< Output bit mask or NULL
-	     const psBitMask *restrict inMask1,	//!< Input bit mask 1
-	     const psBitMask *restrict inMask2 //!< Input bit mask 2
+psBitMaskOp(psBitMask *outMask,	//!< Output bit mask or NULL
+	    const psBitMask *restrict inMask1,	//!< Input bit mask 1
+	    char *operator,		///< bit mask operator (AND, OR, XOR)
+	    const psBitMask *restrict inMask2 //!< Input bit mask 2
     );
 
-/** AND two bit masks */
-psBitMask *
-psAndBitMasks(psBitMask *outMask,	//!< Output bit mask or NULL
-	     const psBitMask *restrict inMask1,	//!< Input bit mask 1
-	     const psBitMask *restrict inMask2 //!< Input bit mask 2
-    );
-
-#endif
+#endif 
@@ -27,21 +27,15 @@
     );
 
-/** OR two bit masks */
+/** apply the given operator to two bit masks */
 psBitMask *
